@@ -26,7 +26,7 @@ import publication
 import aws_cdk.core
 import constructs
 
-from ._jsii import *
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-dax", "1.33.1", __name__, "aws-dax@1.33.1.jsii.tgz")
 
 
 @jsii.implements(aws_cdk.core.IInspectable)
@@ -73,7 +73,7 @@ class CfnCluster(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@
         return jsii.invoke(self, "inspect", [inspector])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
+    def _render_properties(self, props: typing.Mapping[str,typing.Any]) -> typing.Mapping[str,typing.Any]:
         """
         :param props: -
         """
@@ -105,7 +105,7 @@ class CfnCluster(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@
 
     @builtins.property
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[str,typing.Any]:
         return jsii.get(self, "cfnProperties")
 
     @builtins.property
@@ -288,7 +288,7 @@ class CfnCluster(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@
 
     @jsii.data_type(jsii_type="@aws-cdk/aws-dax.CfnCluster.SSESpecificationProperty", jsii_struct_bases=[], name_mapping={'sse_enabled': 'sseEnabled'})
     class SSESpecificationProperty():
-        def __init__(self, *, sse_enabled: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None) -> None:
+        def __init__(self, *, sse_enabled: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None):
             """
             :param sse_enabled: ``CfnCluster.SSESpecificationProperty.SSEEnabled``.
 
@@ -321,7 +321,7 @@ class CfnCluster(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@
 
 @jsii.data_type(jsii_type="@aws-cdk/aws-dax.CfnClusterProps", jsii_struct_bases=[], name_mapping={'iam_role_arn': 'iamRoleArn', 'node_type': 'nodeType', 'replication_factor': 'replicationFactor', 'availability_zones': 'availabilityZones', 'cluster_name': 'clusterName', 'description': 'description', 'notification_topic_arn': 'notificationTopicArn', 'parameter_group_name': 'parameterGroupName', 'preferred_maintenance_window': 'preferredMaintenanceWindow', 'security_group_ids': 'securityGroupIds', 'sse_specification': 'sseSpecification', 'subnet_group_name': 'subnetGroupName', 'tags': 'tags'})
 class CfnClusterProps():
-    def __init__(self, *, iam_role_arn: str, node_type: str, replication_factor: jsii.Number, availability_zones: typing.Optional[typing.List[str]]=None, cluster_name: typing.Optional[str]=None, description: typing.Optional[str]=None, notification_topic_arn: typing.Optional[str]=None, parameter_group_name: typing.Optional[str]=None, preferred_maintenance_window: typing.Optional[str]=None, security_group_ids: typing.Optional[typing.List[str]]=None, sse_specification: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["CfnCluster.SSESpecificationProperty"]]]=None, subnet_group_name: typing.Optional[str]=None, tags: typing.Any=None) -> None:
+    def __init__(self, *, iam_role_arn: str, node_type: str, replication_factor: jsii.Number, availability_zones: typing.Optional[typing.List[str]]=None, cluster_name: typing.Optional[str]=None, description: typing.Optional[str]=None, notification_topic_arn: typing.Optional[str]=None, parameter_group_name: typing.Optional[str]=None, preferred_maintenance_window: typing.Optional[str]=None, security_group_ids: typing.Optional[typing.List[str]]=None, sse_specification: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["CfnCluster.SSESpecificationProperty"]]]=None, subnet_group_name: typing.Optional[str]=None, tags: typing.Any=None):
         """Properties for defining a ``AWS::DAX::Cluster``.
 
         :param iam_role_arn: ``AWS::DAX::Cluster.IAMRoleARN``.
@@ -518,7 +518,7 @@ class CfnParameterGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_
         return jsii.invoke(self, "inspect", [inspector])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
+    def _render_properties(self, props: typing.Mapping[str,typing.Any]) -> typing.Mapping[str,typing.Any]:
         """
         :param props: -
         """
@@ -532,7 +532,7 @@ class CfnParameterGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_
 
     @builtins.property
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[str,typing.Any]:
         return jsii.get(self, "cfnProperties")
 
     @builtins.property
@@ -580,7 +580,7 @@ class CfnParameterGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_
 
 @jsii.data_type(jsii_type="@aws-cdk/aws-dax.CfnParameterGroupProps", jsii_struct_bases=[], name_mapping={'description': 'description', 'parameter_group_name': 'parameterGroupName', 'parameter_name_values': 'parameterNameValues'})
 class CfnParameterGroupProps():
-    def __init__(self, *, description: typing.Optional[str]=None, parameter_group_name: typing.Optional[str]=None, parameter_name_values: typing.Any=None) -> None:
+    def __init__(self, *, description: typing.Optional[str]=None, parameter_group_name: typing.Optional[str]=None, parameter_name_values: typing.Any=None):
         """Properties for defining a ``AWS::DAX::ParameterGroup``.
 
         :param description: ``AWS::DAX::ParameterGroup.Description``.
@@ -667,7 +667,7 @@ class CfnSubnetGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_typ
         return jsii.invoke(self, "inspect", [inspector])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
+    def _render_properties(self, props: typing.Mapping[str,typing.Any]) -> typing.Mapping[str,typing.Any]:
         """
         :param props: -
         """
@@ -681,7 +681,7 @@ class CfnSubnetGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_typ
 
     @builtins.property
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[str,typing.Any]:
         return jsii.get(self, "cfnProperties")
 
     @builtins.property
@@ -729,7 +729,7 @@ class CfnSubnetGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_typ
 
 @jsii.data_type(jsii_type="@aws-cdk/aws-dax.CfnSubnetGroupProps", jsii_struct_bases=[], name_mapping={'subnet_ids': 'subnetIds', 'description': 'description', 'subnet_group_name': 'subnetGroupName'})
 class CfnSubnetGroupProps():
-    def __init__(self, *, subnet_ids: typing.List[str], description: typing.Optional[str]=None, subnet_group_name: typing.Optional[str]=None) -> None:
+    def __init__(self, *, subnet_ids: typing.List[str], description: typing.Optional[str]=None, subnet_group_name: typing.Optional[str]=None):
         """Properties for defining a ``AWS::DAX::SubnetGroup``.
 
         :param subnet_ids: ``AWS::DAX::SubnetGroup.SubnetIds``.
@@ -782,13 +782,6 @@ class CfnSubnetGroupProps():
         return 'CfnSubnetGroupProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
 
 
-__all__ = [
-    "CfnCluster",
-    "CfnClusterProps",
-    "CfnParameterGroup",
-    "CfnParameterGroupProps",
-    "CfnSubnetGroup",
-    "CfnSubnetGroupProps",
-]
+__all__ = ["CfnCluster", "CfnClusterProps", "CfnParameterGroup", "CfnParameterGroupProps", "CfnSubnetGroup", "CfnSubnetGroupProps", "__jsii_assembly__"]
 
 publication.publish()
